/// <reference types="koa" />
import { Middleware } from 'koa';
import { IConfiguration } from './IConfiguration';
import { Configuration } from './Configuration';
import { IContainer, Type, Token, IModuleBuilder } from '@ts-ioc/core';
import { PlatformServer } from '@ts-ioc/platform-server';
import { IApplication, IMiddleware } from './core/index';
import { IServerMiddleware, ServerMiddleware } from './core/servers/index';
/**
 * mvc applaction bootstrap.
 *
 * @export
 * @class Bootstrap
 */
export declare class Bootstrap extends PlatformServer<IConfiguration> implements IModuleBuilder<IConfiguration> {
    private beforeSMdls;
    private afterSMdls;
    private middlewares;
    /**
     * Creates an instance of WebApplication.
     * @param {string} rootdir
     * @param {Type<any>} [appType]
     * @memberof WebApplication
     */
    constructor(rootdir: string);
    /**
     * create new application.
     *
     * @static
     * @param {string} rootdir
     * @returns
     * @memberof WebApplication
     */
    static create(rootdir: string): Bootstrap;
    /**
     * use middleware `fn` or  `MiddlewareFactory`.
     *
     * @param {(IMiddleware | Middleware | Token<any>)} middleware
     * @returns {this}
     * @memberof Bootstrap
     */
    use(middleware: IMiddleware | Middleware | Token<any>): this;
    useServer(middleware: ServerMiddleware | Token<IServerMiddleware>, afterMvc?: boolean): this;
    private _listener;
    useListener(listener: Function): void;
    /**
     * use boostrap to start application.
     *
     * @template T
     * @param {Type<T>} [appModule]
     * @returns {Promise<T>}
     * @memberof Bootstrap
     */
    run<T extends IApplication>(appModule?: Type<any>): Promise<T>;
    /**
     * bootstrap mvc application with App Module.
     *
     * @template T
     * @param {Type<T>} [appModule]
     * @returns {Promise<T>}
     * @memberof Bootstrap
     */
    bootstrap<T extends IApplication>(appModule?: Type<any>): Promise<T>;
    protected setConfigRoot(config: IConfiguration): void;
    protected getDefaultConfig(): Configuration;
    protected getMetaConfig(appModule: Type<any>): IConfiguration;
    protected initContainer(config: IConfiguration, container: IContainer): Promise<IContainer>;
    protected registerDefaultMiddlewars(container: IContainer): void;
    protected registerDefaults(container: IContainer): void;
    protected setupRoutes(config: IConfiguration, container: IContainer): void;
    protected setupMiddwares(app: IApplication, container: IContainer, middlewares: Token<any>[], excludes: Token<any>[]): IApplication;
    protected setupServerMiddwares(app: IApplication, container: IContainer, middlewares: (ServerMiddleware | Token<IServerMiddleware>)[]): void;
    static classAnnations: any;
}
