/// <reference types="koa" />
/// <reference types="node" />
import * as Koa from 'koa';
import { IContainer, InjectToken } from '@ts-ioc/core';
import * as http from 'http';
import * as https from 'https';
import { IConfiguration } from '../IConfiguration';
import { ILogger, ILoggerManager } from '@ts-ioc/logs';
/**
 * Application token.
 */
export declare const ApplicationToken: InjectToken<IApplication>;
/**
 * Applaction interface.
 *
 * @export
 * @interface IApplication
 */
export interface IApplication {
    getKoa(): Koa;
    getConfiguration(): IConfiguration;
    getLoggerManger(): ILoggerManager;
    getLogger(name?: string): ILogger;
    getServer(): http.Server | https.Server;
    use(middleware: Koa.Middleware): any;
}
/**
 * Application of type mvc.
 *
 * @export
 * @class Application
 * @extends {Koa}
 */
export declare class Application {
    private server;
    private koa;
    private _loggerMgr;
    container: IContainer;
    constructor();
    getKoa(): Koa;
    getConfiguration(): IConfiguration;
    getLoggerManger(): ILoggerManager;
    getLogger(name?: string): ILogger;
    getServer(): http.Server | https.Server;
    use(middleware: Koa.Middleware): void;
    static classAnnations: any;
}
